# Fantasy Names
A Python project dedicated to generating names from various bits of fantasy

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

## Installation

TODO: Add this to PyPi

## Usage

TODO: Describe usage here

This project is formatted automatically with [Black](https://black.readthedocs.io/en/latest/). Prior to pushing code to master, please format your code using Black.
